==> connector-service-1.0.0-20200316.035544-151-sources.jar: com/bizvane/connectorservice/entity/icrm/RechargeCardRequestVO.java <==
package com.bizvane.connectorservice.entity.icrm;

import io.swagger.annotations.ApiModelProperty;

public class RechargeCardRequestVO extends IcrmBaseModel {

    @ApiModelProperty(
            value = "储值卡号 （两个参数必填一个）",
            name = "prepaid_card_code",
            required = true,
            example = ""
    )
    private String  prepaid_card_code;

    @ApiModelProperty(
            value = "手机号/会员卡号/vip唯一值 （两个参数必填一个）",
            name = "data",
            required = true,
            example = ""
    )
    private String data;

    @ApiModelProperty(
            value = "会员的memberCode",
            name = "memberCode",
            required = false,
            example = ""
    )
    private String memberCode;

    @ApiModelProperty(
            value = "该接口默认给参",
            name = "bizvane",
            required = true,
            example = ""
    )
    private String bizvane="1";
    public String getPrepaid_card_code() {
        return prepaid_card_code;
    }

    public void setPrepaid_card_code(String prepaid_card_code) {
        this.prepaid_card_code = prepaid_card_code;
    }

    public String getData() {
        return data;
    }

    public void setData(String data) {
        this.data = data;
    }

    public String getBizvane() {
        return bizvane;
    }

    public void setBizvane(String bizvane) {
        this.bizvane = bizvane;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }
}

==> connector-service-1.0.0-20200316.045614-153-sources.jar: com/bizvane/connectorservice/entity/icrm/RechargeCardRequestVO.java <==
package com.bizvane.connectorservice.entity.icrm;

import io.swagger.annotations.ApiModelProperty;

public class RechargeCardRequestVO extends IcrmBaseModel {

    @ApiModelProperty(
            value = "储值卡号 （两个参数必填一个）",
            name = "prepaid_card_code",
            required = true,
            example = ""
    )
    private String  prepaid_card_code;

    @ApiModelProperty(
            value = "手机号/会员卡号/vip唯一值 （两个参数必填一个）",
            name = "data",
            required = true,
            example = ""
    )
    private String data;

    @ApiModelProperty(
            value = "该接口默认给参",
            name = "bizvane",
            required = true,
            example = ""
    )
    private String bizvane="1";

    /**
     * 当前页数
     */
    private int pageNum;

    /**
     * 每页显示数
     */
    private int pageSize;


    public String getPrepaid_card_code() {
        return prepaid_card_code;
    }

    public void setPrepaid_card_code(String prepaid_card_code) {
        this.prepaid_card_code = prepaid_card_code;
    }

    public String getData() {
        return data;
    }

    public void setData(String data) {
        this.data = data;
    }

    public String getBizvane() {
        return bizvane;
    }

    public void setBizvane(String bizvane) {
        this.bizvane = bizvane;
    }

    public int getPageNum() {
        return pageNum;
    }

    public void setPageNum(int pageNum) {
        this.pageNum = pageNum;
    }

    public int getPageSize() {
        return pageSize;
    }

    public void setPageSize(int pageSize) {
        this.pageSize = pageSize;
    }
}
